SystemOrganization addCategory: #'MC2-Tests-Repository-File'!

!MDMonticelloAdaptionTest methodsFor: '*mc2-tests-repository-file' stamp: 'cwp 10/22/2009 12:14'!
testFileRepository
	| repository |
	repository := MDFileRepository named: 'test'.
	[self tryAdapting: (MDFileRepositoryElement for: repository)]
		ensure: [repository destroy]! !

TestCase subclass: #MDByteIndexTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Repository-File'!

!MDByteIndexTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
storeAndRetrieveWithFileSize: aNumber
	|  file stream |
	stream := RWBinaryOrTextStream on: ByteArray new.
	stream next: aNumber put: 0.
	stream reset.
 
	file := MDByteIndex stream: stream keySize: 2 valueSize: 4.
	file at: 'aa' asByteArray put: 'abcd' asByteArray.
	file at: 'ab' asByteArray put: 'qxry' asByteArray.
	file at: 'xy' asByteArray put: '1234' asByteArray.
	self assert: file tally = 3.

	self assert: (file at: 'aa' asByteArray) = 'abcd' asByteArray.
	self assert: (file at: 'ab' asByteArray) = 'qxry' asByteArray.
	self assert: (file at: 'xy' asByteArray) = '1234' asByteArray.
	file at: 'ab' asByteArray put: '9876' asByteArray.
	self assert: (file at: 'ab' asByteArray) = '9876' asByteArray.
	self assert: file tally = 3! !

!MDByteIndexTest methodsFor: 'as yet unclassified' stamp: 'avi 3/13/2005 03:58'!
testStoreAndRetrieve
	self storeAndRetrieveWithFileSize: 100.
	self storeAndRetrieveWithFileSize: 24.
	self should: [self storeAndRetrieveWithFileSize: 12] raise: Error! !

TestCase subclass: #MDKeyedStreamTest
	instanceVariableNames: 'dataStream baseStream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Repository-File'!

!MDKeyedStreamTest methodsFor: 'support' stamp: 'cwp 4/10/2005 16:24'!
append: aSmallInteger
	dataStream 
		appendKey: (self key: aSmallInteger)
		value: (self value: aSmallInteger).
! !

!MDKeyedStreamTest methodsFor: 'support' stamp: 'cwp 4/10/2005 16:19'!
assert: bytes is: aSmallInteger
	self assert: bytes last = aSmallInteger! !

!MDKeyedStreamTest methodsFor: 'support' stamp: 'cwp 5/22/2008 00:11'!
bytes: count containing: aSmallInteger
	| key |
	key := ByteArray new: count.
	key at: key size put: aSmallInteger.
	^ key! !

!MDKeyedStreamTest methodsFor: 'support' stamp: 'cwp 4/10/2005 16:02'!
key: aSmallInteger
	^ self bytes: dataStream keySize containing: aSmallInteger! !

!MDKeyedStreamTest methodsFor: 'running' stamp: 'avi 4/17/2005 01:19'!
setUp
	baseStream := RWBinaryOrTextStream on: (ByteArray new: 100).
	dataStream := MDKeyedStream on: baseStream! !

!MDKeyedStreamTest methodsFor: 'tests' stamp: 'cwp 4/10/2005 16:11'!
testAppend
	self append: 1.
	dataStream keysValuesAndPositionsDo: 
		[:k :v :p |
		self assert: k is: 1.
		self assert: v is: 1.
		self assert: p >= 0]! !

!MDKeyedStreamTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testKeysValuePositions
	| index position |
	1 to: 3 do: [:i | self append: i].
	index := 1.
	position := -1.
	dataStream keysValuesAndPositionsDo: 
		[:k :v :p |
		self assert: k is: index.
		self assert: v is: index.
		self assert: p > position.
		position := p.
		index := index + 1]! !

!MDKeyedStreamTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testPosition
	| position |
	position := dataStream nextValuePosition.
	self append: 1.
	dataStream keysValuesAndPositionsDo: 
		[:k :v :p | self assert: p = position].
! !

!MDKeyedStreamTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testValueAtPosition
	| position |
	self append: 1.
	dataStream keysValuesAndPositionsDo: 
		[:k :v :p | position := p].
	self assert: (dataStream valueAtPosition: position) is: 1! !

!MDKeyedStreamTest methodsFor: 'support' stamp: 'cwp 4/10/2005 16:07'!
value: aSmallInteger
	^ self bytes: dataStream keySize * 2 containing: aSmallInteger! !

MDRepositoryTest subclass: #MDFileRepositoryTest
	instanceVariableNames: 'second tearDownRepositories'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Repository-File'!

!MDFileRepositoryTest methodsFor: 'running' stamp: 'cwp 10/25/2008 15:38'!
addTearDownFilename: aString
	^ tearDownFilenames add: aString! !

!MDFileRepositoryTest methodsFor: 'running' stamp: 'cwp 12/23/2007 00:06'!
destroyRepository: aRepository named: aString
	aRepository close.
	FileDirectory default deleteFileNamed: (aString, '.mcr')! !

!MDFileRepositoryTest methodsFor: 'running' stamp: 'cwp 10/25/2008 19:16'!
isWindows
	"Some tests won't work on Windows, because they simulate the interaction of
	several images using a file repository at the same time. The Windows VM doesn't
	allow more than one filestream on a given file at the same time, so the test fail,
	even though the code works correctly in actual usage. Rather than create more
	elaborate tests, we just skip them on Windows... they run fine with Mac and Unix."
	
	^ FileDirectory default class = DosFileDirectory ! !

!MDFileRepositoryTest methodsFor: 'running' stamp: 'cwp 10/27/2008 23:45'!
newRepository
	^ self noteRepository: (MDFileRepository named: self repositoryFileName)! !

!MDFileRepositoryTest methodsFor: 'running' stamp: 'cwp 10/27/2008 23:45'!
noteRepository: aRepository 
	^ tearDownRepositories add: aRepository! !

!MDFileRepositoryTest methodsFor: 'running' stamp: 'cwp 1/1/2007 10:02'!
repositoryFileName
	^ 'test-file-repository'! !

!MDFileRepositoryTest methodsFor: 'running' stamp: 'cwp 12/23/2007 00:10'!
secondFileName
	^ 'test-file-repository2'! !

!MDFileRepositoryTest methodsFor: 'running' stamp: 'cwp 10/27/2008 23:45'!
secondRepository
	^ second := self noteRepository: (MDFileRepository named: self secondFileName)! !

!MDFileRepositoryTest methodsFor: 'running' stamp: 'cwp 10/25/2008 19:10'!
setUp
	tearDownRepositories := OrderedCollection new.
	super setUp! !

!MDFileRepositoryTest methodsFor: 'running' stamp: 'cwp 10/25/2008 18:59'!
tearDown
	super tearDown.
	tearDownRepositories do: 
		[:each | 
		each close.
		FileDirectory default deleteFileNamed: each name].
	tearDownRepositories := nil! !

!MDFileRepositoryTest methodsFor: 'tests' stamp: 'cwp 10/27/2008 23:45'!
testConcurrentAppend
	| version get |
	self isWindows ifTrue: [ ^ self ].
	second := self noteRepository: self newRepository.
	version := self version.
	repository put: version.
	self 
		assert: (repository get: version hashstamp)
		isEquivalentTo: version.
	get := second get: version hashstamp.
	self assert: get notNil.
	self 
		assert: get
		isEquivalentTo: version! !

!MDFileRepositoryTest methodsFor: 'tests' stamp: 'cwp 10/25/2008 14:54'!
testDeletedFile
	| version result |
	version := self version.
	repository put: version.
	repository close.
	FileDirectory default deleteFileNamed: self repositoryFileName , '.mcr'.
	(repository instVarNamed: 'dataStream') stream reopen.
	
	result := repository get: version hashstamp.
	self assert: result isNil! !

!MDFileRepositoryTest methodsFor: 'tests' stamp: 'cwp 10/27/2008 23:45'!
testReopen
	| version |
	version := self version.
	repository put: version.
	self 
		assert: (repository get: version hashstamp)
		isEquivalentTo: version.
	repository close.
	repository := self noteRepository: self newRepository.
	self 
		assert: (repository get: version hashstamp)
		isEquivalentTo: version! !

!MDFileRepositoryTest methodsFor: 'tests' stamp: 'cwp 10/25/2008 19:13'!
testTruncatedFile
	| result builder alpha beta other |
	self isWindows ifTrue: [^ self].
	builder := MDTestBuilder new.
	alpha := builder versionWith: #alpha.
	beta := builder versionWith: #beta.
	repository put: alpha.
	repository put: beta.
	
	FileDirectory default deleteFileNamed: self repositoryFileName , '.mcr'.
	other := self newRepository.
	other put: alpha.
	(repository instVarNamed: 'dataStream') stream reopen.
	
	result := repository get: alpha hashstamp.
	self deny: result isNil.
	
	result := repository get: beta hashstamp.
	self assert: result isNil.! !
